"""Add users table and update todos

Revision ID: 2_add_users_table_and_update_todos
Revises: 1_initial_create_todos_table
Create Date: 2023-07-20 10:00:00.000000

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = '2_add_users_table_and_update_todos'
down_revision = '1_initial_create_todos_table'
branch_labels = None
depends_on = None


def upgrade():
    # Create users table
    op.create_table(
        'users',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('email', sa.String(), nullable=False),
        sa.Column('username', sa.String(), nullable=False),
        sa.Column('hashed_password', sa.String(), nullable=False),
        sa.Column('is_active', sa.Boolean(), nullable=True, default=True),
        sa.Column('is_superuser', sa.Boolean(), nullable=True, default=False),
        sa.Column(
            'created_at',
            sa.DateTime(timezone=True),
            server_default=sa.text('(CURRENT_TIMESTAMP)'),
            nullable=True,
        ),
        sa.Column('updated_at', sa.DateTime(timezone=True), nullable=True),
        sa.PrimaryKeyConstraint('id'),
    )
    op.create_index(op.f('ix_users_email'), 'users', ['email'], unique=True)
    op.create_index(op.f('ix_users_id'), 'users', ['id'], unique=False)
    op.create_index(op.f('ix_users_username'), 'users', ['username'], unique=True)

    # Add owner_id column to todos table
    op.add_column('todos', sa.Column('owner_id', sa.Integer(), nullable=True))

    # Create foreign key from todos to users
    op.create_foreign_key(
        'fk_todos_owner_id_users',
        'todos', 'users',
        ['owner_id'], ['id'],
    )

    # Update all existing todos to have owner_id = 1 (first user)
    op.execute("UPDATE todos SET owner_id = 1")

    # Make owner_id non-nullable after updating existing todos
    op.alter_column('todos', 'owner_id', nullable=False)


def downgrade():
    # Drop foreign key constraint
    op.drop_constraint('fk_todos_owner_id_users', 'todos', type_='foreignkey')

    # Drop owner_id column from todos
    op.drop_column('todos', 'owner_id')

    # Drop users table
    op.drop_index(op.f('ix_users_username'), table_name='users')
    op.drop_index(op.f('ix_users_id'), table_name='users')
    op.drop_index(op.f('ix_users_email'), table_name='users')
    op.drop_table('users')
